<?xml version="1.0" encoding="UTF-8"?>
<!-- Dies ist lediglich ein Beispielskript, in dem einige der besprochenen Elemente von TEI-XML in HTML umgewandelt werden -->

<!-- Wichtig: im folgenden Wurzelelement wird der TEI-Namespace muss deklariert. In den TEI-Dateien ist er implizit angegeben 
	(im Wurzelelement mit dem Attribut xmlns="http://www.tei-c.org/ns/1.0") und wird daher für alle dem TEI-Wurzelelement 
	untergeordneten	Elemente übernommen.
	Hier wird er explizit und dem Präfix TEI definiert (xmlns:TEI="http://www.tei-c.org/ns/1.0")
	Damit ist es z.B. möglich das TEI-Element <p> vom HTML-Element <p> zu unterscheiden. 
	Die Deklaration hier muss mit der Deklaration im TEI-Dokument übereinstimmen. Wenn sie hier etwas ändern, z.B. die Version
	auf 2.0 ändern, klappt nichts mehr. Probieren Sie's aus. -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:TEI="http://www.tei-c.org/ns/1.0" version="1.0">
	<xsl:output method="html" encoding="UTF-8"/>
	<!-- Wurzelelement ansprechen und HTML-Gerüst bauen -->
	<xsl:template match="/">
		<html>
			<head>
				<title>Testtransformation für TEI-Dokumente</title>
			</head>
			<body>
				<!-- mit dem apply-templates werden alle Regeln, die für untergeordnete Elemente gefunden werden, angewendet -->
				<xsl:apply-templates/>
			</body>
		</html>
	</xsl:template>

	<!-- Nur den TEI:text-Teil auswerten, Header ignorieren -->
	<!-- Implizit gilt immer die Regel, allen Text auszugeben, sofern nicht für 
		ein Element explizit ein Template definiert wird -->
	<xsl:template match="TEI:TEI">
		<xsl:apply-templates select="TEI:text"/>
	</xsl:template>

	<!-- TEI-Absätze in html-Absätze umwandeln. Beachten Sie das handling der Namespaces. Bei TEI:p *muss* der namespace 
		angegeben werden, bei der Ausgabe in ein HTML-Dokument kann darauf verzichtet werden -->
	<xsl:template match="TEI:p">
		<p style="text-indent: 1em;width: 600px; text-align:justify;">
			<xsl:apply-templates/>
		</p>
	</xsl:template>

	<!-- Linegroups in einen eigenen Absatz setzen -->
	<!-- Der test [not(parent::TEI:lg)] prüft, ob es sich nicht um eine verschachtelte lg handelt. 
		Der Absatz wird nur gemacht, wenn es keine lg in einer lg ist. -->
	<xsl:template match="TEI:lg[not(parent::TEI:lg)]">
		<p style="margin-left:30px">
			<xsl:apply-templates/>
		</p>
	</xsl:template>

	<!-- template für lines  -->
	<xsl:template match="TEI:l">

		<!-- Nach jeder Zeile einen Zeilenumbruch ausgeben -->
		<xsl:if test="@n mod 5 = 0">
			<span style="margin-left:-25px; 
				width:20px; 
				display:inline-block; 
				text-align:right; 
				padding-right:5px;">
				<xsl:value-of select="@n"/>
			</span>
		</xsl:if>

		<!-- Zeile ausgeben -->
		<xsl:apply-templates/>

		<br/>
		<!-- Test: Wenn es die letzte Zeile einer linegroup ist, noch einen Zeilenumbruch einfügen
			damit werden die Strophen optisch abgesetzt -->
		<xsl:if test=".=../TEI:l[last()]">
			<br/>
		</xsl:if>
	</xsl:template>

	<!-- template für rhyme; A wird grün ausgegeben, B rot.
		Das ist zwar hässlich, soll hier aber auch nur zur Verdeutlichung dienen, 
		was man theoretisch damit machen kann -->
	<xsl:template match="TEI:rhyme">
		<xsl:choose>
			<xsl:when test="@label='A'">
				<span style="color:green">
					<xsl:apply-templates/>
				</span>
			</xsl:when>
			<xsl:when test="@label='B'">
				<span style="color:red">
					<xsl:apply-templates/>
				</span>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- TEI:q in Anführungszeichen setzen. Hier sind französische Anführungszeichen gewählt, denkbar wären 
		auch deutsche "Gänsefüßchen" oder die wörtliche Rede zu kursivieren -->
	<xsl:template match="TEI:q">
		<xsl:text>«</xsl:text>
		<xsl:apply-templates/>
		<xsl:text>»</xsl:text>
	</xsl:template>
	<xsl:template match="TEI:q[@rend='noquotes']">
		<xsl:apply-templates/>
	</xsl:template>
	


	<!-- sic und corr -->
	<!-- sic-Element wird unterdrückt -->
	<xsl:template match="TEI:sic"/>
	<!-- corr-Element wird angezeigt -->
	<xsl:template match="TEI:corr">
		<span style="text-decoration:underline">
			<xsl:apply-templates/>
		</span>
	</xsl:template>

	<!-- hi, emph usw. werden einfach kursiv gesetzt -->
	<xsl:template match="TEI:emph | TEI:hi | TEI:foreign">
		<i>
			<xsl:apply-templates/>
		</i>
	</xsl:template>

	<!-- linebreaks, falls kodiert, in HTML-linebreaks umwandeln -->
	<xsl:template match="TEI:lb">
		<br/>
	</xsl:template>
</xsl:stylesheet>
